=============
 oslo.config
=============

An OpenStack library for parsing configuration options from the command
line and configuration files.

Contents
========

.. toctree::
   :maxdepth: 2

   reference/index
   cli/index
   configuration/index
   contributor/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

